@@ -6,7 +6,7 @@ from inspect import signature
 from .parser import ArgumentParser, HelpFormatter
 from .util import Arg, ArgparseArg, get_arg, join_strings, format_type, format_table
 from .util import format_arg_help, SimpleFrozenDict, CommandNotFoundError
-from .util import CliParserError, DEFAULT_CONVERTERS
+from .util import CliParserError, CommandExistsError, DEFAULT_CONVERTERS
 
 # Make available for import
 from .util import ExistingPath, ExistingFilePath, ExistingDirPath  # noqa: F401
@@ -112,6 +112,8 @@ class Radicli:
         """The decorator used to wrap command functions."""
 
         def cli_wrapper(cli_func: _CallableT) -> _CallableT:
+            if name in registry:
+                raise CommandExistsError(name)
             sig = signature(cli_func)
             sig_types = {}
             sig_defaults = {}
@@ -131,6 +133,8 @@ class Radicli:
                     args[param_name] = Arg()
             cli_args = []
             for param, arg_info in args.items():
+                if param not in sig_types:  # unknown argument
+                    raise CliParserError(f"argument not found in function: {param}")
 
                 def get_converter(arg_type: Type) -> Optional[Callable[[str], Any]]:
                     return self.converters.get(arg_type, arg_info.converter)
@@ -163,6 +167,19 @@ class Radicli:
 
         return cli_wrapper
 
+    def placeholder(self, name: str, *, description: Optional[str] = None) -> None:
+        """Add empty parent command placeholder with help for subcommands."""
+        if name in self.commands:
+            raise CommandExistsError(name)
+
+        def func(*args, **kwargs) -> None:
+            subcommands = self.subcommands.get(name, {})
+            # If this runs, we want to show the help instead of doing nothing
+            self.parse(["--help"], [], subcommands, name=name, description=description)
+
+        dummy = Command(name=name, func=func, args=[], description=description)
+        self.commands[name] = dummy
+
     def run(self, args: Optional[List[str]] = None) -> None:
         """
         Run the CLI. Should typically be used in the __main__.py nested under a
@@ -172,6 +189,11 @@ class Radicli:
         if len(run_args) <= 1 or run_args[1] == self._help_arg:
             print(self._format_info())
         else:
+            # Make single command CLIs available without command name
+            if len(self.commands) == 1 and len(self.subcommands) <= 1:
+                single_cmd = list(self.commands.keys())[0]
+                if run_args[1] != single_cmd:
+                    run_args.insert(1, single_cmd)
             command = run_args.pop(1)
             args = run_args[1:]
             subcommands = self.subcommands.get(command, {})
@@ -179,8 +201,7 @@ class Radicli:
                 if not subcommands:
                     raise CommandNotFoundError(command, list(self.commands))
                 # Add a dummy parent to support subcommands without parents
-                dummy = Command(name=command, func=lambda *x, **y: None, args=[])
-                self.commands[command] = dummy
+                self.placeholder(command)
             cmd = self.commands[command]
             values = self.parse(
                 args,
